@@ -1,4 +1,4 @@
-//    Copyright (C) 2009 Dirk Vanden Boer <dirk.vdb@gmail.com>
+//    Copyright (C) 2010 Dirk Vanden Boer <dirk.vdb@gmail.com>
 //
 //    This program is free software; you can redistribute it and/or modify
 //    it under the terms of the GNU General Public License as published by
@@ -17,11 +17,11 @@
 #ifndef IMAGE_TYPES_H
 #define IMAGE_TYPES_H
 
-typedef enum ImageTypeEnum
+typedef enum ThumbnailerImageTypeEnum
 {
     Png,
     Jpeg,
     Unknown
-} ImageType;
+} ThumbnailerImageType;
 
 #endif
